/**
 *****************************************************************************
 * Name: MusicHandler 
 * Description: SAX handler for the parsing of sample "music collection" files
 *****************************************************************************
 */

import org.xml.sax.*;
import java.util.Vector;

/**
  * Event handler class for flyweight demos.
  *
  * The only relevant code for the flyweight example is in the  
  * startElement,EndElement and chardata examples.
  *
  * This code can be substantially optimized, however, due to 
  * didactic reasons, readability and simplicity have come first.
  */
public class MusicHandler extends HandlerBase
{
  public void startElement (String name, AttributeList attributes)
  {
      if(name.equals("cd"))
	  myCD = new CD();
      else if(name.equals("title"))
	  current = 1;
      else if(name.equals("year"))
	  current = 2;
      else if(name.equals("artist"))
	  current = 3;
  }

  /**
    * When the element is done, add it to the cds catalog
    *
    * @see org.xml.sax.DocumentHandler#endElement
    */
  public void endElement (String name)
  {
      allCDs.addElement(myCD);
  }

    // Exercise: Add an endDocument handler that 
    //           print the results

  /**
    * Print a message for character data.
    *
    * @see org.xml.sax.DocumentHandler#characters
    */
  public void characters (char ch[], int start, int length)
  {
      if(current==1)
	  myCD.setTitle(new String(ch,start,length));
      if(current==2)
	  myCD.setYear(new Integer(new String(ch,start,length)).intValue());
      if(current==3)
	  myCD.setArtist(   // This is the crucial part: the artistFactory is called
              		    // and then we get an artist.
			 af.getArtist(new String(ch,start,length)));
  }

    int current = 0;  // Simplistic way to know which element is being treated.
                      // 1 = title, 2 = year, 3 = artist
    CD myCD;
    ArtistFactory af = new ArtistFactory();
    Vector allCDs = new Vector();
}












